@@ -22,6 +22,7 @@ has 'output_fasta_files'    => ( is => 'ro', isa => 'Bool',     default  => 0 );
 has 'spreadsheet_basename'  => ( is => 'ro', isa => 'Str',      default  => 'mlst_results' ); 
 has 'output_phylip_files'   => ( is => 'ro', isa => 'Bool',     default  => 0 ); 
 has 'show_contamination_instead_of_alt_matches' => ( is => 'ro', isa => 'Bool',   default => 1 ); 
+has 'report_lowest_st'      => ( is => 'ro', isa => 'Bool', default => 0 );
 
 has 'parallel_processes'    => ( is => 'ro', isa => 'Int',      default  => 1 ); 
 
@@ -53,7 +54,7 @@ sub _generate_spreadsheet_rows
 
       } else {  # problems occuring during storage or retrieval will throw a warning
         print qq|No message received from child process $pid!\n|;
-      }
+    }
     }
   );
   
@@ -74,7 +75,8 @@ sub _generate_spreadsheet_rows
       blastn_exec        => $self->blastn_exec,
       output_directory   => $self->output_directory,
       output_fasta_files => $self->output_fasta_files,
-      show_contamination_instead_of_alt_matches => $self->show_contamination_instead_of_alt_matches
+      show_contamination_instead_of_alt_matches => $self->show_contamination_instead_of_alt_matches,
+      report_lowest_st   => $self->report_lowest_st
     );
     my @result_rows;
     push(@result_rows, ($fasta_sequence_type_results->_spreadsheet_row_obj->header_row,
@@ -100,7 +102,7 @@ sub create_result_files
   my($self) = @_;
   exit unless $self->input_fasta_files_exist;
   $self->_generate_spreadsheet_rows;
-  
+
   my $spreadsheet = Bio::MLST::Spreadsheet::File->new(
     header                          => pop(@{$self->_spreadsheet_header}),
     spreadsheet_allele_numbers_rows => $self->_spreadsheet_allele_numbers_rows,
@@ -165,13 +167,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bio::MLST::Check - Multilocus sequence type checking using blast
 
 =head1 VERSION
 
-version 1.133090
+version 1.150910
 
 =head1 SYNOPSIS
 
