@@ -17,6 +17,7 @@ has 'base_directory'        => ( is => 'ro', isa => 'Str',      required => 1 );
 has 'parallel_processes'    => ( is => 'ro', isa => 'Int',      default  => 1 ); # max parallel processes
 has 'verbose'               => ( is => 'rw', isa => 'Bool',     default  => 0 ); # output search progress and number of matches
 has 'report_all_mlst_db'    => ( is => 'rw', isa => 'Bool',     default  => 0 ); # report all mlst databases searched
+has 'report_lowest_st'      => ( is => 'rw', isa => 'Bool',     default  => 0 );
 
 has 'raw_input_fasta_files' => ( is => 'ro', isa => 'ArrayRef', required => 1 );
 has 'makeblastdb_exec'      => ( is => 'ro', isa => 'Str',      required => 1 ); 
@@ -88,7 +89,7 @@ sub _run_mlst_for_species_list
     my $parallel_process_fa_file = int($self->parallel_processes/@{$self->_species_list}) ? int($self->parallel_processes/@{$self->_species_list}) : 1;
 
     # Run for each species - output to csv files named 0001,0002,etc.
-    my $pm = new Parallel::ForkManager();
+    my $pm = new Parallel::ForkManager($self->parallel_processes);
     for(my $i=1; $i <= @{$self->_species_list}; $i++)
     {
         $pm->start and next; # fork here
@@ -108,7 +109,8 @@ sub _run_mlst_for_species_list
             parallel_processes    => $parallel_process_fa_file,
             output_fasta_files    => $self->output_fasta_files,
             output_phylip_files   => $self->output_phylip_files,
-            show_contamination_instead_of_alt_matches => $self->show_contamination_instead_of_alt_matches
+            show_contamination_instead_of_alt_matches => $self->show_contamination_instead_of_alt_matches,
+            report_lowest_st      => $self->report_lowest_st
             );
         $multiple_fastas->create_result_files;
 
@@ -241,13 +243,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bio::MLST::CheckMultipleSpecies - High throughput multilocus sequence typing (MLST) checking against several MLST databases.
 
 =head1 VERSION
 
-version 1.133090
+version 1.150910
 
 =head1 SYNOPSIS
 
